@@ -45,6 +45,8 @@
 #include "models/tracks/tracksmodel.h"
 #include "models/folders/foldersmodel.h"
 
+#include "kde/server.h"
+
 #define VVAVE_URI "org.maui.vvave"
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
@@ -76,10 +78,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon("qrc:/assets/vvave.png"));
 
-    MauiApp::instance()->setIconName("qrc:/assets/vvave.png");
-
     KLocalizedString::setApplicationDomain("vvave");
-    KAboutData about(QStringLiteral("vvave"), i18n("Vvave"), VVAVE_VERSION_STRING, i18n("Play your music collection."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())),QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("vvave"), i18n("Vvave"), VVAVE_VERSION_STRING, i18n("Organize and listen to your music."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())),QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
@@ -87,32 +87,60 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     about.setBugAddress("https://invent.kde.org/maui/vvave/-/issues");
     about.setOrganizationDomain(VVAVE_URI);
     about.setProgramLogo(app.windowIcon());
+    about.setDesktopFileName("org.kde.vvave");
+    about.addComponent("TagLib");
 
     KAboutData::setApplicationData(about);
 
+    MauiApp::instance()->setIconName("qrc:/assets/vvave.png");
+
     QCommandLineParser parser;
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
 
     const QStringList args = parser.positionalArguments();
+    QStringList paths;
+
+    if (!args.isEmpty())
+    {
+        for(const auto &path : args)
+            paths << QUrl::fromUserInput(path).toString();
+    }
+
+#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
+    if (AppInstance::attachToExistingInstance(QUrl::fromStringList(paths)))
+    {
+        // Successfully attached to existing instance of Nota
+        return 0;
+    }
+
+    AppInstance::registerService();
+#endif
+
+    auto server =  std::make_unique<Server>();
 
     QQmlApplicationEngine engine;
     const QUrl url(QStringLiteral("qrc:/main.qml"));
 
     qDebug() << "APP LOADING SPEED TESTS" << 3;
 
-    QObject::connect(&engine, &QQmlApplicationEngine::objectCreated, &app, [url, args](QObject *obj, const QUrl &objUrl)
+    QObject::connect(&engine, &QQmlApplicationEngine::objectCreated, &app, [url, args, &server](QObject *obj, const QUrl &objUrl)
     {
         if (!obj && url == objUrl)
             QCoreApplication::exit(-1);
 
+        server->setQmlObject(obj);
+
         if (!args.isEmpty())
-            vvave::instance()->openUrls(args);
+            server->openFiles(args);
 
     }, Qt::QueuedConnection);
 
+    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+
     qmlRegisterSingletonInstance<vvave>(VVAVE_URI, 1, 0, "Vvave", vvave::instance());
+    qmlRegisterSingletonInstance<Server>(VVAVE_URI, 1, 0, "Server", server.get());
 
     qmlRegisterType<TracksModel>(VVAVE_URI, 1, 0, "Tracks");
     qmlRegisterType<AlbumsModel>(VVAVE_URI, 1, 0, "Albums");
