@@ -22,8 +22,6 @@ PlaylistsModel::PlaylistsModel(QObject *parent)
         this->list[index] = item;
         emit this->updateModel(index, {});
     });
-
-    this->setList();
 }
 
 const FMH::MODEL_LIST &PlaylistsModel::items() const
@@ -34,7 +32,10 @@ const FMH::MODEL_LIST &PlaylistsModel::items() const
 void PlaylistsModel::setList()
 {
     emit this->preListChanged();
-    this->list << this->defaultPlaylists();
+    if(m_limit == 9999)
+    {
+        this->list << this->defaultPlaylists();
+    }
     this->list << this->tags();
     emit this->postListChanged();
 }
@@ -90,7 +91,11 @@ FMH::MODEL_LIST PlaylistsModel::tags()
         const auto map = item.toMap();
         auto res = packPlaylist(map.value("tag").toString());
         res[FMH::MODEL_KEY::ICON] = map.value("icon").toString();
-        list << res;
+
+        if(list.count() <= m_limit)
+        {
+            list << res;
+        }
         return list;
     });
 }
@@ -129,3 +134,21 @@ void PlaylistsModel::removePlaylist(const int &index) // TODO
         emit this->postItemRemoved();
     }
 }
+
+void PlaylistsModel::componentComplete()
+{
+    this->setList();
+}
+
+int PlaylistsModel::limit() const
+{
+    return m_limit;
+}
+
+void PlaylistsModel::setLimit(int newLimit)
+{
+    if (m_limit == newLimit)
+        return;
+    m_limit = newLimit;
+    emit limitChanged();
+}
